summaryrefslogtreecommitdiff
path: root/test/fixedbugs/issue5493.go
diff options
context:
space:
mode:
Diffstat (limited to 'test/fixedbugs/issue5493.go')
-rw-r--r--test/fixedbugs/issue5493.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/test/fixedbugs/issue5493.go b/test/fixedbugs/issue5493.go
index affc07b58..2ee0398af 100644
--- a/test/fixedbugs/issue5493.go
+++ b/test/fixedbugs/issue5493.go
@@ -31,9 +31,10 @@ func run() error {
}
func main() {
// Does not work on 32-bits due to partially conservative GC.
// Try to enable when we have fully precise GC.
- if runtime.GOARCH != "amd64" {
+ if runtime.GOARCH != "amd64" || runtime.Compiler == "gccgo" {
return
}
count = N
@@ -31,9 +31,10 @@ func run() error {
}
func main() {
- // Does not work on 32-bits due to partially conservative GC.
+ // Does not work on 32-bits, or with gccgo, due to partially
+ // conservative GC.
// Try to enable when we have fully precise GC.